<?php

namespace Teknisa\FIS\Factories;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Fiscal\Entities\Codreceitacontr;

class Fis46000ParametrizacaoCodigosApuracaoFactory {

    protected $entityManager;
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    /*******************************************************************
	*                  Funções Referentes a aba                        *
	*                  Código da Receita                               *
	*******************************************************************/
    
    
    public function updateCodreceitacontr($params){
        $sql = "UPDATE CODRECEITACONTR SET IDDEBSCPINC = :NOVOIDDEBSCPINC, IDPERIODICREC = :NOVOIDPERIODICREC, DTULTATU = :DTULTATU, NRORGULTATU = :NRORGULTATU, CDOPERULTATU = :CDOPERULTATU WHERE IDDEBSCPINC = :IDDEBSCPINC AND IDPERIODICREC = :IDPERIODICREC AND CDVARIACAO = :CDVARIACAO AND CDRECEITACONTR = :CDRECEITACONTR AND CDIMPOSTO = :CDIMPOSTO AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getCodreceitacontr($params){
        $codreceitacontr = $this->entityManager->getRepository(Codreceitacontr::class)->findOneBy($params);
        return $codreceitacontr;
    }
    
    public function validaIntervaloDatasCodigoNatureza($cdreceitaest, $dtinivalid, $nrseqcodreceest, $sgestado, $dtfimvalid) {
        #sets parameter data
        $params                      = array();
        $params['P_CDRECEITAEST']    = $cdreceitaest;
        $params['P_DTINIVALID']      = $dtinivalid;
        $params['P_NRSEQCODRECEEST'] = $nrseqcodreceest;
        $params['P_SGESTADO']        = $sgestado;
        $params['P_DTFIMVALID']      = $dtfimvalid;

        #defines function query
        $sql = "SELECT NRSEQCODRECEEST, SGESTADO, CDRECEITAEST, DTINIVALID, DTFIMVALID , MAX(ERRO) AS ERRO
                    FROM (SELECT NRSEQCODRECEEST, SGESTADO, CDRECEITAEST, DTINIVALID, DTFIMVALID,
                               CASE WHEN :P_DTFIMVALID IS NULL THEN 'DtFim_Inf'
                                    WHEN :P_DTFIMVALID >= DTINIVALID THEN 'DtInt_Inv'
                                    ELSE '' END AS ERRO
                        FROM CODRECEITAEST
                        WHERE SGESTADO       = :P_SGESTADO
                           AND NRSEQCODRECEEST <> :P_NRSEQCODRECEEST
                           AND CDRECEITAEST       = :P_CDRECEITAEST
                           AND  :P_DTINIVALID < DTINIVALID
                        UNION ALL
                        SELECT NRSEQCODRECEEST, SGESTADO, CDRECEITAEST, DTINIVALID, DTFIMVALID,
                               CASE WHEN DTFIMVALID IS NULL THEN 'DtFimOld_Inf'
                                    WHEN DTFIMVALID >= :P_DTINIVALID THEN 'DtInt_Inv'
                                    ELSE '' END AS ERRO
                        FROM CODRECEITAEST
                        WHERE SGESTADO       = :P_SGESTADO
                           AND NRSEQCODRECEEST <> :P_NRSEQCODRECEEST
                           AND CDRECEITAEST       = :P_CDRECEITAEST
                           AND :P_DTINIVALID  > DTINIVALID
                        UNION ALL
                        SELECT NRSEQCODRECEEST, SGESTADO, CDRECEITAEST, DTINIVALID, DTFIMVALID,
                               'DtInt_Inv' AS ERRO
                         FROM CODRECEITAEST
                        WHERE SGESTADO       = :P_SGESTADO
                           AND NRSEQCODRECEEST <> :P_NRSEQCODRECEEST
                           AND CDRECEITAEST       = :P_CDRECEITAEST
                           AND DTINIVALID     = :P_DTINIVALID)
                    GROUP BY NRSEQCODRECEEST, SGESTADO, CDRECEITAEST,  DTINIVALID, DTFIMVALID";


        #prepares query and executes it with parameters
        $std = $this->connection->prepare($sql);
        $std->execute($params);

        #fetch all result rows and returns
        return $std->fetchAll();
    }
    public function busca ($nrorg, $sgestado){
        $sql = "SELECT *
                FROM CODRECEITAEST
                WHERE NRORG = :P_NRORG AND
                SGESTADO    = :SGESTADO";

        $params = array(
            'P_NRORG'=>$nrorg,
            'SGESTADO'=>$sgestado
            );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    public function deleteCodigoReceita ($nrorg, $sgestado, $cdreceitaest){
        $sql = "DELETE
                FROM CODRECEITAEST
                WHERE NRORG = :P_NRORG AND
                SGESTADO    = :SGESTADO AND
                CDRECEITAEST = :CDRECEITAEST";

        $params = array(
            'P_NRORG'=>$nrorg,
            'SGESTADO'=>$sgestado,
            'CDRECEITAEST'=>$cdreceitaest,
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /********************************************************************
	*                  Funções Referentes a aba                        *
	*                  Código de Ajuste                                 *
	********************************************************************/
	
	
	public function deleteCodigoAjusteEstadual ($nrorg, $sgestado, $idtpajuste){
        $sql = "DELETE
                FROM CODAJUSTEEFDICMS
                WHERE NRORG = :P_NRORG AND
                SGESTADO    = :SGESTADO AND
                IDTPAJUSTE = :IDTPAJUSTE AND
                IDTPCODRECEITA = 'E'";

        $params = array(
            'P_NRORG'=>$nrorg,
            'IDTPAJUSTE'=>$idtpajuste,
            'SGESTADO'=>$sgestado,
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function deleteCodigoAjusteFederal ($nrorg){
        $sql = "DELETE
                FROM CODAJUSTEEFDICMS
                WHERE NRORG = :P_NRORG AND
                SGESTADO IS NULL AND
                IDTPCODRECEITA = 'F'";

        $params = array(
            'P_NRORG'=>$nrorg
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function validaIntervaloDatas($cdajuste, $dtinivalid, $nrseqcodajuste, $idtpajuste, $sgestado, $dtfimvalid) {
        #sets parameter data
        $params                     = array();
        $params['P_CDAJUSTE']       = $cdajuste;
        $params['P_DTINIVALID']     = $dtinivalid;
        $params['P_NRSEQCODAJUSTE'] = $nrseqcodajuste;
        $params['P_IDTPAJUSTE']     = $idtpajuste;
        $params['P_SGESTADO']       = $sgestado;
        $params['P_DTFIMVALID']     = $dtfimvalid;

        #defines function query
        $sql = "SELECT NRSEQCODAJUSTE, SGESTADO, IDTPAJUSTE, CDAJUSTE, DSAJUSTE, DTINIVALID, DTFIMVALID , MAX(ERRO) AS ERRO
                    FROM (SELECT NRSEQCODAJUSTE, SGESTADO, IDTPAJUSTE, CDAJUSTE, DSAJUSTE, DTINIVALID, DTFIMVALID,
                               CASE WHEN :P_DTFIMVALID IS NULL THEN 'DtFim_Inf'
                                    WHEN :P_DTFIMVALID >= DTINIVALID THEN 'DtInt_Inv'
                                    ELSE '' END AS ERRO
                        FROM CODAJUSTEEFDICMS
                        WHERE SGESTADO       = :P_SGESTADO
                           AND IDTPAJUSTE     = :P_IDTPAJUSTE
                           AND NRSEQCODAJUSTE <> :P_NRSEQCODAJUSTE
                           AND CDAJUSTE       = :P_CDAJUSTE
                           AND  :P_DTINIVALID < DTINIVALID
                        UNION ALL
                        SELECT NRSEQCODAJUSTE, SGESTADO, IDTPAJUSTE, CDAJUSTE, DSAJUSTE, DTINIVALID, DTFIMVALID,
                               CASE WHEN DTFIMVALID IS NULL THEN 'DtFimOld_Inf'
                                    WHEN DTFIMVALID >= :P_DTINIVALID THEN 'DtInt_Inv'
                                    ELSE '' END AS ERRO
                        FROM CODAJUSTEEFDICMS
                        WHERE SGESTADO       = :P_SGESTADO
                           AND IDTPAJUSTE     = :P_IDTPAJUSTE
                           AND NRSEQCODAJUSTE <> :P_NRSEQCODAJUSTE
                           AND CDAJUSTE       = :P_CDAJUSTE
                           AND :P_DTINIVALID  > DTINIVALID
                        UNION ALL
                        SELECT NRSEQCODAJUSTE, SGESTADO, IDTPAJUSTE, CDAJUSTE, DSAJUSTE, DTINIVALID, DTFIMVALID,
                               'DtInt_Inv' AS ERRO
                         FROM CODAJUSTEEFDICMS
                        WHERE SGESTADO       = :P_SGESTADO
                           AND IDTPAJUSTE     = :P_IDTPAJUSTE
                           AND NRSEQCODAJUSTE <> :P_NRSEQCODAJUSTE
                           AND CDAJUSTE       = :P_CDAJUSTE
                           AND DTINIVALID     = :P_DTINIVALID)
                    GROUP BY NRSEQCODAJUSTE, SGESTADO, IDTPAJUSTE, CDAJUSTE, DSAJUSTE, DTINIVALID, DTFIMVALID";


        #prepares query and executes it with parameters
        $std = $this->connection->prepare($sql);
        $std->execute($params);

        #fetch all result rows and returns
        return $std->fetchAll();
    }
    
}