<?php
namespace Teknisa\FIS\Modules\Acessorias\Controllers;

use Teknisa\FIS\Modules\Acessorias\Services\Fis26000GmaIcmsStService;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Error;

class Fis26000GmaIcmsStController {

    protected $giaService;

    public function __construct(EntityManager $entityManager, Fis26000GmaIcmsStService $giaService) {
        $this->entityManager    = $entityManager;
        $this->giaService = $giaService;
        set_time_limit(0);
    }

    /*
     * Função para realizar a exportação da GIA.
     */
    public function exportarGia(DTO\Request $request, DTO\Response $response) {
        try {
          
            $row = $request->getRow();
            
            $row["NMARQUIVO"] = str_replace(' ', '', $row["NMARQUIVO"]);

            // Chama a função de exportação.
            $fileName = $this->giaService->exportarGia($row);

            // Retorna o nome do arquivo exportado.
            $response->addDataset(new DataSet('columnsToReturn', array("fileName" => $fileName)));
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /*
     * Função para retornar os dados "Op. Transferẽncia" e "Versão" da última linha exportada
     * para ser posto ao abrir a tela.
     */
    public function findLastRowData(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $lastRowData = $this->giaService->findLastRowData($row);
        $response->addDataSet(new DataSet('columnsToReturn', array("lastRowData" => $lastRowData)));
    }
    
    public function findAgendamento(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            
            $rows = $this->giaService->findAgendamento();
            
            $dataSet = new DataSet('agendobrigacess_fis26000', $rows);
            $response->setDataSets(array($dataSet));
            
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    } 
    
    public function saveAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            $this->giaService->saveAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteAgendamento(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            // Chama a função de validação.
            $this->giaService->deleteAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function execAgendamentoGiaIcmsSt(DTO\Request $request, DTO\Response $response) {
        try {
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            
            $row = $request->getParameters();
            
            $this->giaService->execAgendamento($row);
            
            $this->entityManager->commit();

        } catch(\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
}